function P = newton_dd_poly(X,Y)

% function P = newton_dd(X,Y)
% Newton divided differences. 
% Outputs function handle 'P' to Lagrange polynomial assoc'd to
% Newton's Divided Differences
% X = x-value nodes (row vector)
% Y = f(X) i.e. f sampled at the nodes (column vector)

n = length(X);
F = zeros(n,n);
F(:,1) = Y';

for i=1:n-1
    for j = 1:i
        F(i+1,j+1) = (F(i+1,j)- F(i,j))/(X(i+1)-X(i-j+1));           
    end
end


a = diag(F)';

% cell array of function handles
G = cell(1,n);
G{1} = 1;
G{2} = @(x)(x-X(1));


for i=3:n
    xim = X(i-1)
    G{i} = @(x)(G{i-1}(x).*(x-xim)); %input function handles into cell
end

P = @(x) a(1);

%create function handle P which is Lagrange Poly from
%Newton's Divided Differences
for i=2:n
    P = @(x)(P(x) + a(i)*G{i}(x))
end



end
 